@@ -1,6 +1,6 @@
 
 import os
-import Image#,re,csv,timeside
+from PIL import Image
 import math
 
 from django.db import models
